@@ -241,20 +241,8 @@ kolab_itest_koma_ksettings_envset (KolabSettingsHandler *ksettings,
 
 	/* We cannot sanely set a sync strategy for each folder in this testcase
 	 * since we do not want to depend on the server folders. If no strategy
-	 * is set, KolabMailSynchronizer will assume the default. In order to silence
-	 * KolabSettingsHandler's complaints about non-existing tables when requesting
-	 * the sync strategy, we explicitly set the default for the INBOX.
+	 * is set, KolabMailSynchronizer will assume the default.
 	 */
-	ok = kolab_settings_handler_set_value (ksettings,
-	                                       KOLAB_SETTINGS_HANDLER_TBL_SYNCSTRATEGY,
-	                                       "INBOX",
-	                                       KOLAB_SYNC_STRATEGY_DEFAULT,
-	                                       &tmp_err);
-
-	if (! ok) {
-		g_propagate_error (err, tmp_err);
-		return FALSE;
-	}
 
 	return TRUE;
 }
@@ -463,7 +451,7 @@ test_kolab_mail_access (KolabFolderContextID context)
 	/* create settings handler object with
 	 * a dummy CamelKolabIMAPXSettings */
 	camel_settings = g_object_new (CAMEL_TYPE_KOLAB_IMAPX_SETTINGS, NULL);
-	ksettings = kolab_settings_handler_new (camel_settings);
+	ksettings = kolab_settings_handler_new (camel_settings, backend);
 	g_object_unref (camel_settings);
 
 	/* configure settings */
@@ -486,7 +474,6 @@ test_kolab_mail_access (KolabFolderContextID context)
 
 	/* configure mail access subsystem */
 	ok = kolab_mail_access_configure (kmailaccess,
-	                                  backend,
 	                                  ksettings,
 	                                  &tmp_err);
 	if (! ok)
@@ -512,7 +499,7 @@ test_kolab_mail_access (KolabFolderContextID context)
 	                                               &tmp_err);
 	if (! ok)
 		goto test_part_cleanup;
-	
+
 	/* test folder creation and deletion */
 	ok = test_kolab_mail_access_create_delete_source (kmailaccess,
 	                                                  &tmp_err);
